@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.002000';
+our $VERSION = '2.003000';
 
 1;
 
@@ -20,7 +20,7 @@ GeoIP2 - Perl API for MaxMind's GeoIP2 web services and databases
 
 =head1 VERSION
 
-version 2.002000
+version 2.003000
 
 =head1 DESCRIPTION
 
@@ -42,6 +42,26 @@ L<MaxMind::DB::Reader::XS>, then the XS implementation will be loaded
 automatically. The XS implementation is approximately 100x faster than the
 pure Perl implementation.
 
+=head1 VALUES TO USE FOR DATABASE OR HASH KEYS
+
+B<We strongly discourage you from using a value from any C<names> accessor as
+a key in a database or hash.>
+
+These names may change between releases. Instead we recommend using one of the
+following:
+
+=over 4
+
+=item * L<GeoIP2::Record::City> - C<< $city->geoname_id >>
+
+=item * L<GeoIP2::Record::Continent> - C<< $continent->code >> or C<< $continent->geoname_id >>
+
+=item * L<GeoIP2::Record::Country> and L<GeoIP2::Record::RepresentedCountry> - C<< $country->iso_code >> or C<< $country->geoname_id >>
+
+=item * L<GeoIP2::Record::Subdivision> - C<< $subdivision->iso_code >> or C<< $subdivision->geoname_id >>
+
+=back
+
 =head1 INTEGRATION WITH GEONAMES
 
 GeoNames (L<http://www.geonames.org/>) offers web services and downloadable
@@ -122,7 +142,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack Graham Knop Mateu X Hunter
+=for stopwords Andy Jack E. Choroba Graham Knop Mateu X Hunter
 
 =over 4
 
@@ -132,17 +152,21 @@ Andy Jack <github@veracity.ca>
 
 =item *
 
+E. Choroba <choroba@matfyz.cz>
+
+=item *
+
 Graham Knop <haarg@haarg.org>
 
 =item *
 
-Mateu X Hunter <hunter@missoula.org>
+Mateu X Hunter <mhunter@maxmind.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
