@@ -3,7 +3,7 @@ package GeoIP2::Database::Reader;
 use strict;
 use warnings;
 
-our $VERSION = '2.002000';
+our $VERSION = '2.003000';
 
 use Data::Validate::IP 0.24
     qw( is_ipv4 is_ipv6 is_private_ipv4 is_private_ipv6 );
@@ -14,6 +14,7 @@ use GeoIP2::Model::City;
 use GeoIP2::Model::ConnectionType;
 use GeoIP2::Model::Country;
 use GeoIP2::Model::Domain;
+use GeoIP2::Model::Enterprise;
 use GeoIP2::Model::Insights;
 use GeoIP2::Model::ISP;
 use GeoIP2::Types qw( Str );
@@ -144,6 +145,15 @@ sub domain {
     );
 }
 
+sub enterprise {
+    my $self = shift;
+    return $self->_model_for_address(
+        'Enterprise',
+        type_check => qr/^GeoIP2-Enterprise$/,
+        @_
+    );
+}
+
 sub isp {
     my $self = shift;
     return $self->_model_for_address(
@@ -178,7 +188,7 @@ GeoIP2::Database::Reader - Perl API for GeoIP2 databases
 
 =head1 VERSION
 
-version 2.002000
+version 2.003000
 
 =head1 SYNOPSIS
 
@@ -215,6 +225,12 @@ method point you called.
 
 If the database cannot be read, the reader class throws an exception.
 
+=head1 IP GEOLOCATION USAGE
+
+IP geolocation is inherently imprecise. Locations are often near the center of
+the population. Any location provided by a GeoIP2 database should not be used
+to identify a particular address or household.
+
 =head1 CONSTRUCTOR
 
 This class has a single constructor method:
@@ -318,7 +334,7 @@ This method returns a L<GeoIP2::Model::AnonymousIP> object.
 
 =head2 $reader->metadata()
 
-This method returns a L<MaxMind::DB:Metadata> object containing information
+This method returns a L<MaxMind::DB::Metadata> object containing information
 about the database.
 
 =head1 EXCEPTIONS
@@ -371,7 +387,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
