@@ -3,10 +3,7 @@ package GeoIP2::Model::Insights;
 use strict;
 use warnings;
 
-our $VERSION = '2.002000';
-
-use GeoIP2::Types qw( HashRef object_isa_type );
-use Sub::Quote qw( quote_sub );
+our $VERSION = '2.003000';
 
 use Moo;
 
@@ -28,7 +25,7 @@ GeoIP2::Model::Insights - Model class for GeoIP2 Precision: Insights
 
 =head1 VERSION
 
-version 2.002000
+version 2.003000
 
 =head1 SYNOPSIS
 
@@ -155,7 +152,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
