@@ -3,7 +3,7 @@ package GeoIP2::Record::Traits;
 use strict;
 use warnings;
 
-our $VERSION = '2.002000';
+our $VERSION = '2.003000';
 
 use GeoIP2::Types qw( Bool BoolCoercion IPAddress NonNegativeInt Str );
 use Sub::Quote qw( quote_sub );
@@ -24,6 +24,12 @@ has autonomous_system_organization => (
     predicate => 'has_autonomous_system_organization',
 );
 
+has connection_type => (
+    is        => 'ro',
+    isa       => Str,
+    predicate => 'has_connection_type',
+);
+
 has domain => (
     is        => 'ro',
     isa       => Str,
@@ -37,6 +43,13 @@ has is_anonymous_proxy => (
     coerce  => BoolCoercion,
 );
 
+has is_legitimate_proxy => (
+    is      => 'ro',
+    isa     => Bool,
+    default => quote_sub(q{ 0 }),
+    coerce  => BoolCoercion,
+);
+
 has is_satellite_provider => (
     is      => 'ro',
     isa     => Bool,
@@ -76,7 +89,7 @@ GeoIP2::Record::Traits - Contains data for the traits record associated with an
 
 =head1 VERSION
 
-version 2.002000
+version 2.003000
 
 =head1 SYNOPSIS
 
@@ -111,7 +124,7 @@ This returns the autonomous system number
 the IP address.
 
 This attribute is only available from the City and Insights web service
-endpoints.
+endpoints and the GeoIP2 Enterprise database.
 
 =head2 $traits_rec->autonomous_system_organization()
 
@@ -120,7 +133,15 @@ number (L<http://en.wikipedia.org/wiki/Autonomous_system_(Internet)>) for the IP
 address.
 
 This attribute is only available from the City and Insights web service
-endpoints.
+endpoints and the GeoIP2 Enterprise database.
+
+=head2 $traits_rec->connection_type()
+
+This returns the connection type associated with the IP address. It may take
+the following values: C<Dialup>, C<Cable/DSL>, C<Corporate>, or C<Cellular>.
+Additional values may be added in the future.
+
+This attribute is only available in the GeoIP2 Enterprise database.
 
 =head2 $traits_rec->domain()
 
@@ -128,7 +149,7 @@ This returns the second level domain associated with the IP address. This will
 be something like "example.com" or "example.co.uk", not "foo.example.com".
 
 This attribute is only available from the City and Insights web service
-endpoints.
+endpoints and the GeoIP2 Enterprise database.
 
 =head2 $traits_rec->ip_address()
 
@@ -147,10 +168,18 @@ determine whether the IP address is used by an anonymizing service.
 
 This attribute is returned by all end points.
 
+=head2 $traits_rec->is_legitimate_proxy()
+
+This attribute returns true if MaxMind believes this IP address to be a
+legitimate proxy, such as an internal VPN used by a corporation
+
+This attribute is only available in the GeoIP2 Enterprise database.
+
 =head2 $traits_rec->is_satellite_provider()
 
-I<Deprecated.> Please see our L<GeoIP2 Anonymous IP
-database|https://www.maxmind.com/en/geoip2-anonymous-ip-database>.
+I<Deprecated.> Due to the increased coverage by mobile carriers, very few
+satellite providers now serve multiple countries. As a result, the
+output does not provide sufficiently relevant data for us to maintain it.
 
 This attribute is returned by all end points.
 
@@ -159,14 +188,14 @@ This attribute is returned by all end points.
 This returns the name of the ISP associated with the IP address.
 
 This attribute is only available from the City and Insights web service
-endpoints.
+endpoints and the GeoIP2 Enterprise database.
 
 =head2 $traits_rec->organization()
 
 This returns the name of the organization associated with the IP address.
 
 This attribute is only available from the City and Insights web service
-endpoints.
+endpoints and the GeoIP2 Enterprise database.
 
 =head2 $traits_rec->user_type()
 
@@ -207,7 +236,8 @@ the following values:
 
 =back
 
-This attribute is only available from the Insights end point.
+This attribute is only available from the Insights end point and the GeoIP2
+Enterprise database.
 
 =head1 AUTHORS
 
@@ -233,7 +263,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2016 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
